@@ -11,6 +11,7 @@ from pychoir import (
     DictContainsAllOf,
     GreaterThan,
     HasLength,
+    IsEmpty,
     IsInstance,
     IsNotPresentOr,
     Len,
@@ -19,6 +20,14 @@ from pychoir import (
 )
 
 
+def test_is_empty():
+    assert {'a': []} == {'a': IsEmpty()}
+    assert ['foo', '', 'bar'] == ['foo', IsEmpty(), 'bar']
+    assert not 'foo' == IsEmpty()
+
+    assert str(IsEmpty()) == 'IsEmpty()'
+
+
 def test_has_length():
     assert Len is HasLength
 
